@@ -36,9 +36,9 @@
 
 #include "checksumverifier.h"
 
-#include <ntqfile.h>
-#include <ntqdir.h>
-#include <ntqapplication.h>
+#include <tqfile.h>
+#include <tqdir.h>
+#include <tqapplication.h>
 
 #include <stdio.h>
 
