@@ -346,7 +346,7 @@ class Thread;
  * @author Jernej Kos <kostko@jweb-network.net>
  */
 class EventHandler : public TQObject {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Construct a new event handler.
