@@ -68,7 +68,7 @@ class TransferFile;
  */
 class FailedTransfer : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Constructs a new failed transfer object. The actual transfer
@@ -129,7 +129,7 @@ friend class TransferDir;
 friend class Manager;
 friend class KFTPSession::Session;
 friend class KFTPSession::Connection;
-Q_OBJECT
+TQ_OBJECT
 public:
     Transfer(TQObject *parent, Type type);
     ~Transfer();
