@@ -56,7 +56,7 @@ namespace KFTPWidgets {
  */
 class MainActions : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
 friend class MainWindow;
 friend class KFTPWidgets::SystemTray;
 public:
