@@ -105,7 +105,7 @@ MainWindow::MainWindow()
 
   // Set the shell's ui resource file
   setXMLFile("kftpgrabberui.rc");
-  connect(TDEApplication::kApplication(), SIGNAL(shutDown()), this, SLOT(appShutdown()));
+  connect(TDEApplication::kApplication(), TQ_SIGNAL(shutDown()), this, TQ_SLOT(appShutdown()));
 
   // Restore size and position
   resize(KFTPCore::Config::size());
@@ -120,9 +120,9 @@ MainWindow::MainWindow()
   // Load custom commands
   KFTPCore::CustomCommands::Manager::self()->load();
 
-  connect(KFTPQueue::Manager::self(), SIGNAL(queueUpdate()), this, SLOT(slotUpdateStatusBar()));
-  connect(KFTPBookmarks::Manager::self(), SIGNAL(update()), this, SLOT(initBookmarkMenu()));
-  connect(KFTPCore::Config::self(), SIGNAL(configChanged()), this, SLOT(slotConfigChanged()));
+  connect(KFTPQueue::Manager::self(), TQ_SIGNAL(queueUpdate()), this, TQ_SLOT(slotUpdateStatusBar()));
+  connect(KFTPBookmarks::Manager::self(), TQ_SIGNAL(update()), this, TQ_SLOT(initBookmarkMenu()));
+  connect(KFTPCore::Config::self(), TQ_SIGNAL(configChanged()), this, TQ_SLOT(slotConfigChanged()));
 
   m_trafficGraph = 0L;
   m_bookmarkMenu = 0L;
@@ -146,7 +146,7 @@ MainWindow::MainWindow()
   KFTPSession::Manager::self()->spawnLocalSession(KFTPSession::RightSide);
 
   // Load bookmarks
-  TQTimer::singleShot(500, this, SLOT(slotReadBookmarks()));
+  TQTimer::singleShot(500, this, TQ_SLOT(slotReadBookmarks()));
 
   // Check for the uirc file
   if (TDEGlobal::dirs()->findResource("appdata", xmlFile()) == TQString::null) {
@@ -264,7 +264,7 @@ void MainWindow::initTrafficGraph()
 {
   // Setup traffic graph
   m_graphTimer = new TQTimer(this);
-  connect(m_graphTimer, SIGNAL(timeout()), this, SLOT(slotUpdateTrafficGraph()));
+  connect(m_graphTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotUpdateTrafficGraph()));
   m_graphTimer->start(1000);
 
   // Create and configure the traffic graph
@@ -304,7 +304,7 @@ void MainWindow::initBookmarkMenu()
     m_walletMenu = new TDEActionMenu(i18n("Sites In TDEWallet"), loadSmallIcon("wallet_open"));
 
   m_bookmarkMenu->popupMenu()->insertItem(loadSmallIcon("bookmark"), i18n("Edit Bookmarks..."), 1);
-  m_bookmarkMenu->popupMenu()->connectItem(1, this, SLOT(showBookmarkEditor()));
+  m_bookmarkMenu->popupMenu()->connectItem(1, this, TQ_SLOT(showBookmarkEditor()));
   m_bookmarkMenu->insert(m_zeroconfMenu);
 
   if (KFTPCore::Config::showWalletSites())
