@@ -52,7 +52,7 @@ FilterWidget::FilterWidget(TQWidget *parent, DetailsView *view)
     m_filterSymlinks(true),
     m_caseSensitive(false)
 {
-  connect(view, SIGNAL(itemsChanged()), this, SLOT(updateSearch()));
+  connect(view, TQ_SIGNAL(itemsChanged()), this, TQ_SLOT(updateSearch()));
 }
 
 bool FilterWidget::itemMatches(const TQListViewItem *item, const TQString &pattern) const
@@ -82,7 +82,7 @@ TQPopupMenu *FilterWidget::createPopupMenu()
   TQPopupMenu *popup = KLineEdit::createPopupMenu();
   
   TQPopupMenu *subMenu = new TQPopupMenu(popup);
-  connect(subMenu, SIGNAL(activated(int)), this, SLOT(slotOptionsMenuActivated(int)));
+  connect(subMenu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotOptionsMenuActivated(int)));
   
   popup->insertSeparator();
   popup->insertItem(i18n("Filter Options"), subMenu);
