@@ -50,7 +50,7 @@ namespace KFTPWidgets {
  * Widget that animates itself into a position relative to an anchor widget.
  */
 class PopupMessage : public OverlayWidget {
-Q_OBJECT
+TQ_OBJECT
 public:
     /**
      * Possible animation effects.
