@@ -70,13 +70,13 @@ SystemTray::SystemTray(MainWindow *parent)
   slotUpdateBookmarks();
 
   // Let our bookmarks be up to date
-  connect(KFTPBookmarks::Manager::self(), SIGNAL(update()), this, SLOT(slotUpdateBookmarks()));
+  connect(KFTPBookmarks::Manager::self(), TQ_SIGNAL(update()), this, TQ_SLOT(slotUpdateBookmarks()));
   
   m_actions->m_fileConnectAction->plug(contextMenu(), 1);
   m_bookmarkMenu->plug(contextMenu(), 1);
   
   // Ensure that we actually quit
-  connect(this, SIGNAL(quitSelected()), this, SLOT(slotQuitSelected()));
+  connect(this, TQ_SIGNAL(quitSelected()), this, TQ_SLOT(slotQuitSelected()));
 }
 
 SystemTray::~SystemTray()
@@ -110,7 +110,7 @@ void SystemTray::showBalloon(const TQString &text)
   KWin::setOnAllDesktops(m_balloon->winId() , true);
 
   // Hide the balloon after 5 sec
-  TQTimer::singleShot(5000, this, SLOT(slotHideBalloon()));
+  TQTimer::singleShot(5000, this, TQ_SLOT(slotHideBalloon()));
 }
 
 void SystemTray::slotHideBalloon()
